Enumeration
LfbEventEndReason
since: 0.0
Description [src]
Enum values used to indicate why the feedbacks for an event ended.
Available since: 0.0
Members
LFB_EVENT_END_REASON_NOT_FOUND-
There was no feedback in the current theme for this event so no feedback was provided to the user.
- Value:
-1 - Nickname:
not-found - Available since: 0.0
- Value:
LFB_EVENT_END_REASON_NATURAL-
All feedbacks finished playing their natural length.
- Value:
0 - Nickname:
natural - Available since: 0.0
- Value:
LFB_EVENT_END_REASON_EXPIRED-
Feedbacks ran until the set timeout expired.
- Value:
1 - Nickname:
expired - Available since: 0.0
- Value:
LFB_EVENT_END_REASON_EXPLICIT-
The feedbacks were ended explicitly.
- Value:
2 - Nickname:
explicit - Available since: 0.0
- Value: